/*
 * Copyright 2024 KylinSoft Co., Ltd.
 *
 * This program is free software: you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation, either version 3 of the License, or (at your option) any later
 * version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program. If not, see <https://www.gnu.org/licenses/>.
 */

#include <assert.h>
#include <fstream>
#include <iostream>
#include "xunfeivisionengine.h"

void writeBinaryDataToFile(const std::string &filename,
                           const std::vector<char> &data) {
    std::ofstream outputFile(filename,
                             std::ios::out | std::ios::binary | std::ios::app);
    if (!outputFile.is_open()) {
        std::cerr << "Failed to open file for writing." << std::endl;
        return;
    }

    outputFile.write(data.data(), data.size());

    if (!outputFile.good()) {
        std::cerr << "Error occurred while writing to file." << std::endl;
    } else {
        std::cout << "Binary data has been written to file: " << filename
                  << std::endl;
    }

    outputFile.close();
}

void testVision() {
    XunfeiVisionEngine *engine = new XunfeiVisionEngine();

    const std::string configJson =
        u8R"({"appId":"fakeAppId", "apiKey":"fakeApiKey", "secretKey":"fakeSecretKey"})";
    engine->setConfig(configJson);

    engine->setPrompt2ImageNumber(1);
    engine->setPrompt2ImageStyle(16);
    engine->setPrompt2ImageSize(1024, 1024);
    int imageCount = 0;
    engine->setPrompt2ImageCallback(
        [&imageCount](ai_engine::lm::vision::ImageData imageData) -> void {
            std::cout << "image format: " << imageData.format << std::endl;
            std::cout << "image height: " << imageData.height << std::endl;
            std::cout << "image width: " << imageData.width << std::endl;
            std::cout << "image index: " << imageData.index << std::endl;
            std::cout << "image total: " << imageData.total << std::endl;
            std::cout << "image data size: " << imageData.imageData.size()
                      << std::endl;
            writeBinaryDataToFile("test" + std::to_string(imageCount++) +
                                      ".jpg",
                                  imageData.imageData);
            std::cout << "image error message: " << imageData.error.getMessage()
                      << std::endl;
        });

    ai_engine::lm::EngineError error;
    auto ret = engine->prompt2Image("骑马", error);
    std::cout << "prompt2Image result: " << error.getMessage() << std::endl;
    assert(ret == true);
}

int main(int argc, char *argv[]) {
    testVision();
    return 0;
}