/*
 * Copyright 2024 KylinSoft Co., Ltd.
 *
 * This program is free software: you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation, either version 3 of the License, or (at your option) any later
 * version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program. If not, see <https://www.gnu.org/licenses/>.
 */

#include "xunfeispeechengine.h"

XunfeiSpeechEngine::XunfeiSpeechEngine() : d(new XunfeiSpeechEnginePrivate()) {}

XunfeiSpeechEngine::~XunfeiSpeechEngine() { delete d; }

std::string XunfeiSpeechEngine::backendName() { return d->backendName(); }

void XunfeiSpeechEngine::setConfig(const std::string &config) {
    d->setConfig(config);
}

void XunfeiSpeechEngine::setRecognizingCallback(
    ai_engine::lm::speech::RecognitionResultCallback callback) {
    d->setRecognizingCallback(callback);
}

void XunfeiSpeechEngine::setRecognizedCallback(
    ai_engine::lm::speech::RecognitionResultCallback callback) {
    d->setRecognizedCallback(callback);
}

void XunfeiSpeechEngine::setSynthesizingCallback(
    ai_engine::lm::speech::SynthesisResultCallback callback) {
    d->setSynthesizingCallback(callback);
}

void XunfeiSpeechEngine::setSynthesizedCallback(
    ai_engine::lm::speech::FinishedCallback callback) {
    d->setSynthesizedCallback(callback);
}

bool XunfeiSpeechEngine::initContinuousRecognitionModule(
    ai_engine::lm::EngineError &error) {
    return d->initContinuousRecognitionModule(error);
}

bool XunfeiSpeechEngine::startContinuousRecognition(
    const std::string &params, ai_engine::lm::EngineError &error) {
    return d->startContinuousRecognition(params, error);
}

bool XunfeiSpeechEngine::writeContinuousRecognitionAudioData(
    const std::vector<char> &audioData, ai_engine::lm::EngineError &error) {
    return d->writeContinuousRecognitionAudioData(audioData, error);
}

bool XunfeiSpeechEngine::stopContinuousRecognition(
    ai_engine::lm::EngineError &error) {
    return d->stopContinuousRecognition(error);
}

bool XunfeiSpeechEngine::destroyContinuousRecognitionModule(
    ai_engine::lm::EngineError &error) {
    return d->destroyContinuousRecognitionModule(error);
}

bool XunfeiSpeechEngine::initRecognizeOnceModule(
    ai_engine::lm::EngineError &error) {
    return d->initRecognizeOnceModule(error);
}

bool XunfeiSpeechEngine::recognizeOnce(const std::string &params,
                                       const std::vector<char> &audioData,
                                       ai_engine::lm::EngineError &error) {
    return d->recognizeOnce(params, audioData, error);
}

bool XunfeiSpeechEngine::destroyRecognizeOnceModule(
    ai_engine::lm::EngineError &error) {
    return d->destroyRecognizeOnceModule(error);
}

bool XunfeiSpeechEngine::initContinuousSynthesisModule(
    ai_engine::lm::EngineError &error) {
    return d->initContinuousSynthesisModule(error);
}

bool XunfeiSpeechEngine::startContinuousSynthesis(
    const std::string &params, ai_engine::lm::EngineError &error) {
    return d->startContinuousSynthesis(params, error);
}

bool XunfeiSpeechEngine::writeContinuousSynthesisText(
    const std::string &text, ai_engine::lm::EngineError &error) {
    return d->writeContinuousSynthesisText(text, error);
}

bool XunfeiSpeechEngine::stopContinuousSynthesis(
    ai_engine::lm::EngineError &error) {
    return d->stopContinuousSynthesis(error);
}

bool XunfeiSpeechEngine::destroyContinuousSynthesisModule(
    ai_engine::lm::EngineError &error) {
    return d->destroyContinuousSynthesisModule(error);
}

bool XunfeiSpeechEngine::initSynthesizeOnceModule(
    ai_engine::lm::EngineError &error) {
    return d->initSynthesizeOnceModule(error);
}

bool XunfeiSpeechEngine::synthesizeOnce(const std::string &params,
                                        const std::string &text,
                                        ai_engine::lm::EngineError &error) {
    return d->synthesizeOnce(params, text, error);
}

bool XunfeiSpeechEngine::destroySynthesizeOnceModule(
    ai_engine::lm::EngineError &error) {
    return d->destroySynthesizeOnceModule(error);
}